@@ -69,6 +69,7 @@ AboutDialog::AboutDialog( QWidget *parent)
     "    <li>Konstantin Goudkov: sort branches</li>"
     "    <li>Jakob Hilmer: image drag and drop in 1.8.1, &quot;About vym&quot; window patch </li>"
     "    <li>Edward Wang: adding close tab buttons</li>"
+    "    <li>p0llox (Pierre): various patches for Debian packaging</li>"
     "  </ul>"
     "</li>"
     "<li> Patches in previous vym versions"
@@ -85,7 +86,7 @@ AboutDialog::AboutDialog( QWidget *parent)
     "    <li>Scott Dillman and Patrick Spendrin: Recent windows patches</li>"
     "    <li>Jon Ciesla: Sourceforge file releases</li>"
     "    <li>Andrew Ng, Juha Ruotsalainen and Thomas Kriener: Older windows patches</li>"
-    "    <li>Xavier Oswald, Christoph Thielecke and Steffen Joeris: Debian packaging</li>"
+    "    <li>Xavier Oswald, Christoph Thielecke, Pierre, and Steffen Joeris: Debian packaging</li>"
     "  </ul>"
     "<li> General"
     "  <ul>"
