@@ -90,18 +90,25 @@ TaskEditor::TaskEditor(QWidget *)
 
     // Initialize column widths
     QString s;
-    for (int i=0; i<7; i++)
+    for (int i=0; i<6; i++)
     {
 	s=QString("/taskeditor/columnWidth/%1").arg(i);
 	if (settings.contains (s) )
 	    view->setColumnWidth (i, settings.value(s, 100).toInt() );
     }
+
+    // Initialize display of parents of a task
+    bool ok;
+    int i=settings.value ("/taskeditor/showParentsLevel", 0).toInt(&ok);
+    if (ok) taskModel->setShowParentsLevel(i);
+
 }
 
 TaskEditor::~TaskEditor()
 {
     settings.setValue ("/taskeditor/filterMap",actionToggleFilterMap->isChecked());
     settings.setValue ("/taskeditor/filterActive",actionToggleFilterActive->isChecked());
+    settings.setValue ("/taskeditor/showParentsLevel",taskModel->getShowParentsLevel() );
     for (int i=0; i<7; i++)
 	settings.setValue (QString("/taskeditor/columnWidth/%1").arg(i),view->columnWidth(i) );
 }
@@ -165,6 +172,11 @@ bool TaskEditor::select (Task *task)
     return false;
 }
 
+void TaskEditor::clearSelection()
+{
+    view->selectionModel()->clearSelection();
+}
+
 void TaskEditor::selectionChanged ( const QItemSelection & selected, const QItemSelection & )
 {// FIXME-3 what, if multiple selection in MapEditor?
     // Avoid segfault on quit, when selected is empty
