@@ -3,6 +3,8 @@
 
 #include <QtGui>
 
+#include "noteobj.h"
+
 enum EditorState {inactiveEditor,emptyEditor,filledEditor};
 
 class TextEditor :public QMainWindow
@@ -11,10 +13,10 @@ public:
     TextEditor();
     ~TextEditor();
 
+    void init(const QString &ename);
     void reset();
     bool isEmpty();
-    void setShowWithMain (bool);
-    bool showWithMain ();
+    void setFont (const QFont &);
     void setFontHint(const QString&);
     QString getFontHint();
     QString getFontHintDefault();
@@ -23,6 +25,7 @@ public:
     void setFilenameHint (const QString&);
     QString getFilenameHint ();
     QString getText();
+    NoteObj getNote();
 
     bool findText(const QString &, const QTextDocument::FindFlags &); 
     bool findText(const QString &, const QTextDocument::FindFlags &,int i); 
@@ -76,6 +79,7 @@ private slots:
     void setState (EditorState);
 
 protected:
+    QString editorName;	    // "note" or "heading" editor, used for settings
     QTextEdit *e;
     QPoint lastPos;	    // save last position of window
     QString filename;
@@ -85,7 +89,6 @@ protected:
     QBrush filledPaper;	    // depending on the state
     QBrush inactivePaper;   // depending on the state
     EditorState state;
-    bool showwithmain;	    // same visibility as mainwindow?
     bool blockChangedSignal;
 
     QFont varFont;
@@ -93,6 +96,10 @@ protected:
     QComboBox *comboFont, *comboSize;
     
     QToolBar *editToolBar;
+    QToolBar *fontToolBar;
+    QToolBar *fontHintsToolBar;
+    QToolBar *formatToolBar;
+
     QAction *actionFileLoad,
     *actionFileSave,
     *actionFileSaveAs,
