@@ -379,10 +379,12 @@ public:
     ImageItem* createImage(BranchItem *dst);	//!< Create image
 
 public:	
-    bool createLink(Link *l, bool createMO=false);	    //!< Create XLink 
+    bool createLink(Link *l);	//!< Create XLink, will create MO automatically if needed 
     QColor getXLinkColor();
     int getXLinkWidth();
     Qt::PenStyle getXLinkPenStyle();
+    QString getXLinkStyleBegin();
+    QString getXLinkStyleEnd();
 
     AttributeItem* addAttribute();
     AttributeItem* addAttribute(BranchItem *dst, AttributeItem* );
@@ -488,9 +490,11 @@ public:
     QStringList getVymLinks();		    // return paths in subtree
     void followXLink (int);
     void editXLink ();
-
-
-
+    void setXLinkColor(const QString &);
+    void setXLinkLineStyle(const QString &);
+    void setXLinkStyleBegin(const QString &);
+    void setXLinkStyleEnd(const QString &);
+    void setXLinkWidth(int);
 
 ////////////////////////////////////////////
 // Scripting
@@ -601,6 +605,8 @@ private:
 
     QColor defLinkColor;	// default color for links
     QPen defXLinkPen;		// default pen for xlinks
+    QString defXLinkStyleBegin; // default style begin
+    QString defXLinkStyleEnd; ; // default style end
     LinkableMapObj::ColorHint linkcolorhint;// use heading color or own color
     LinkableMapObj::Style linkstyle;	    // default style for links
     QFont defaultFont;
@@ -626,6 +632,11 @@ public:
     void setMapDefXLinkPen (const QPen &p);
     QPen getMapDefXLinkPen();
 
+    void setMapDefXLinkStyleBegin( const QString &s);
+    QString getMapDefXLinkStyleBegin();
+    void setMapDefXLinkStyleEnd  ( const QString &s);
+    QString getMapDefXLinkStyleEnd();
+
     /*!  Move absolutly to (x,y).  */	
     void move    (const double &x, const double &y);
 
