@@ -460,6 +460,11 @@ bool parseVYMHandler::readMapAttr (const QXmlAttributes& a)
     }
     model->setMapDefXLinkPen (pen);
 
+    if (!a.value( "defXLinkStyleBegin").isEmpty() ) 
+        model->setMapDefXLinkStyleBegin( a.value( "defXLinkStyleBegin" ) );
+    if (!a.value( "defXLinkStyleEnd").isEmpty() ) 
+        model->setMapDefXLinkStyleEnd( a.value( "defXLinkStyleEnd" ) );
+
     if (!a.value( "mapZoomFactor").isEmpty() ) 
 	model->setMapZoomFactor(a.value("mapZoomFactor").toDouble());
     if (!a.value( "mapRotationAngle").isEmpty() ) 
@@ -732,7 +737,7 @@ bool parseVYMHandler::readXLinkAttr (const QXmlAttributes& a)
 		    bool okx;
 		    pen.setWidth(a.value ("width").toInt (&okx, 10));
 		}
-		model->createLink (li,true);	// create MO by default
+		model->createLink (li);
 	    }
 	}           
     }	
@@ -745,7 +750,7 @@ bool parseVYMHandler::readLinkNewAttr (const QXmlAttributes& a)
     // (before there was beginBranch and endBranch)
     //
     // Starting in 1.13.2 xlinks are no longer subitems of branches,
-    // but listed at the end of the data in a map. This make handling 
+    // but listed at the end of the data in a map. This makes handling 
     // of links much safer and easier
 
     if (!a.value( "beginID").isEmpty() ) 
@@ -760,6 +765,8 @@ bool parseVYMHandler::readLinkNewAttr (const QXmlAttributes& a)
 		li->setBeginBranch ( (BranchItem*)beginBI );
 		li->setEndBranch ( (BranchItem*)endBI);
 
+		model->createLink (li);
+
 		bool okx;
 		QPen pen=li->getPen();
 		if (!a.value( "type").isEmpty() ) 
@@ -772,7 +779,6 @@ bool parseVYMHandler::readLinkNewAttr (const QXmlAttributes& a)
 		    col.setNamedColor(a.value("color"));
 		    pen.setColor (col);
 		}
-
 		if (!a.value( "width").isEmpty() ) 
 		{
 		    pen.setWidth(a.value ("width").toInt (&okx, 10));
@@ -783,7 +789,11 @@ bool parseVYMHandler::readLinkNewAttr (const QXmlAttributes& a)
 		}
 		li->setPen (pen);
 
-		model->createLink (li,true);	// create MO by default
+		if (!a.value( "styleBegin").isEmpty() ) 
+                    li->setStyleBegin( a.value( "styleBegin" ) );
+		if (!a.value( "styleEnd").isEmpty() ) 
+                    li->setStyleEnd( a.value( "styleEnd" ) );
+
 
 		XLinkObj *xlo=(XLinkObj*)(li->getMO() );
 		if (xlo && !a.value( "c0").isEmpty() )
